<?php
/**
 * BigWigs Starter Content
 * 
 * Based on Twenty Twenty theme starter content
 * @link https://make.wordpress.org/core/2016/11/30/starter-content-for-themes-in-4-7/
 * 
 */

/**
 * Function to return the array of starter content for the theme.
 *
 * Passes it through the `blogbaster_starter_content` filter before returning.
 *
 * @return array a filtered array of args for the starter_content.
 */
function blogbaster_get_starter_content() {

	// Define and register starter content to showcase the theme on new sites.
	$starter_content = array(
		// Specify the core-defined pages
		'posts'       => array(
			'front' => array(
				'post_type'    => 'page',
				'post_title'   => __( 'Front', 'blogbaster' ),
				'post_content' => 
					'<!-- wp:spacer -->
					<div style="height:100px" aria-hidden="true" class="wp-block-spacer"></div>
					<!-- /wp:spacer -->
					<!-- wp:query {"queryId":65,"query":{"perPage":6,"pages":0,"offset":0,"postType":"post","categoryIds":[],"tagIds":[],"order":"desc","orderBy":"date","author":"","search":"","exclude":[],"sticky":"exclude","inherit":false},"displayLayout":{"type":"flex","columns":3}} -->
					<div class="wp-block-query"><!-- wp:post-template -->
					<!-- wp:group {"className":"card"} -->
					<div class="wp-block-group card"><!-- wp:post-featured-image {"isLink":true,"align":"wide"} /-->

					<!-- wp:group {"className":"card-body"} -->
					<div class="wp-block-group card-body"><!-- wp:post-title {"isLink":true} /-->

					<!-- wp:post-excerpt /--></div>
					<!-- /wp:group -->

					<!-- wp:group {"className":"card-footer"} -->
					<div class="wp-block-group card-footer"><!-- wp:post-date /--></div>
					<!-- /wp:group --></div>
					<!-- /wp:group -->
					<!-- /wp:post-template --></div>
					<!-- /wp:query -->'
			),
			'about'=> array(
				'post_type'    => 'page',
				'post_title'   => __( 'About', 'blogbaster' ),
				'post_content' => __( 'Blogbaster is a blogging theme that allows your reader to focus on your content. Blogbaster theme is designed for news agencies, travel blogs, business magazine, food recipes and all type of publishing or review site. Blogbaster theme is a compatible with Block Editor and WooCommerce plugin and also includes a featured post (pictured in the screenshot), custom logo support, footer widget area, sidebar position (left, right or w/o) setting, a search overlay modal, a social menu with icons.', 'blogbaster' ),
			),
			'blog'=> array(
				'post_type'    => 'page',
				'post_title'   => __( 'Blog Page', 'blogbaster' )
			),
		),

		// Default to a static front page and assign the front and posts pages.
		'options'     => array(
			'show_on_front'  => 'page', // 'blog'
			'page_on_front'  => '{{front}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set the Header Banner section theme mods
		'theme_mods'  => array(
			'blog_layout' => 'grid',
			'single_header_display' => 'alt',
			'sidebar_position' => 'none'
		),

		// Set up nav menu and assign to the "primary" location.
		'nav_menus'   => array(
			'primary'  => array(
				'name'  => __( 'Primary', 'blogbaster' ),
				'items' => array(
					'link_home',
					'page_about',
					'page_blog'
				),
			)
		),
	);

	/**
	 * Filters theme array of starter content.
	 *
	 * @param array $starter_content Array of starter content.
	 */
	return apply_filters( 'blogbaster_starter_content', $starter_content );

}
