<?php
/**
 * Functions which hooking
 *
 * @package blogbaster
 */

function blogbaster_get_pre_footer(){
	if( has_nav_menu( 'footer' ) || has_nav_menu( 'social' ) ) {
		get_template_part( 'template-parts/pre-footer' );
	}
}
add_action('blogbaster_before_footer','blogbaster_get_pre_footer');

function blogbaster_blog_wrap_start(){
	if ( get_theme_mod( 'blog_layout' ) == 'grid' ) {
		echo '<div class="grid row">';
	}
}
add_action('blogbaster_before_index_loop','blogbaster_blog_wrap_start');

function blogbaster_blog_wrap_end(){
	if ( get_theme_mod( 'blog_layout' ) == 'grid' ) {
		echo '</div>';
	}

	if( get_theme_mod( 'blog_pagination_mode' ) == 'numeric' ){
		the_posts_pagination();
	}
	else{
		the_posts_navigation();
	}
}
add_action('blogbaster_after_index_loop','blogbaster_blog_wrap_end');


function blogbaster_entry_summary(){
	global $post;
	$has_more = strpos( $post->post_content, '<!--more' );

	if ( $has_more ) {
		the_content();
	} else {
		the_excerpt();
	}

	wp_link_pages( array(
		'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'blogbaster' ),
		'after'  => '</div>',
	) );
}
add_action( 'blogbaster_entry_summary', 'blogbaster_entry_summary' );

/**
 *
 * Primary menu output function.
 *
 */
function blogbaster_main_menu(){
	if( has_nav_menu('primary') ) {
	    wp_nav_menu(
	    	array(
	            'theme_location'  => 'primary',
	            'container' 	  => false,
	            //'container_class' => 'nav-fill w-100',
	            'menu_id'         => false,
	            'menu_class'      => 'navbar-nav nav-fill w-100', // nav-fill w-100
	            'depth'           => 3,
	            'walker'          => new Blogbaster_WP_Bootstrap_Navwalker(),
	            'fallback_cb'     => 'Blogbaster_WP_Bootstrap_Navwalker::fallback',
	        )
	    );
	}
}
add_action('blogbaster_primary_menu','blogbaster_main_menu');
 
/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function blogbaster_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'blogbaster_pingback_header' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function blogbaster_body_classes( $classes ) {
    /* using mobile browser */
    if ( wp_is_mobile() ){
        $classes[] = 'wp-is-mobile';
    }
    else{
        $classes[] = 'wp-is-not-mobile';
    }	
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	// Adds a class if the front-page
	if ( is_front_page() ) {
		$classes[] = 'front-page';
	}
	// Adds a class if the customizer preview
	if ( is_customize_preview() ) {
		$classes[] = 'customizer-preview';
	}
	// Adds a class of custom-background-image to sites with a custom background image.
	if ( get_background_image() ) {
		$classes[] = 'custom-background-image';
	}
	// Adds a class of has-thumbnail.
	if ( ( is_singular() && !is_front_page() && has_post_thumbnail() )
	|| ( is_home() && blogbaster_is_featured_jumbotron() ) 
	|| ( is_front_page() && get_theme_mod('banner_bg_image') ) ) {
		$classes[] = 'has-thumbnail';
	}
	// Adds a class of group-blog to sites with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}
	// Adds a class of no-sidebar to sites without active sidebar.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'blogbaster_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the article element.
 * @return array
 */
function blogbaster_post_classes( $classes ) {
	$classes[] = ( has_post_thumbnail() ? 'has-thumbnail' : 'no-thumbnail' );
	
	if ( is_front_page() || is_home() || is_archive() ) {
		if ( get_post_type() != 'page' ) {
			$classes[] = 'post-preview';
		}
	}

	if ( is_singular( array('post', 'page') ) && ! is_front_page() ) {
		if ( get_theme_mod( 'content_boxed' ) == 1 ) {
			if ( get_theme_mod( 'single_card_style' ) == 'shadow' ) {
				$classes[] = 'card card-shadow mb-4';
			} elseif ( get_theme_mod( 'single_card_style' ) == 'border' ) {
				$classes[] = 'card card-border mb-4';
			} else {
				$classes[] = 'card card-noborder mb-4';
			}
			
		} else {
			$classes[] = 'mb-4';
		}
	}
	
	if ( is_home() || is_archive() || is_front_page() ) {
		if ( get_post_type() == 'post' ) {
			if ( get_theme_mod( 'blog_layout' ) == 'grid' ) {
				$classes[] = 'grid-item card h-100';
			}
			elseif ( !get_theme_mod( 'blog_layout' ) 
				|| get_theme_mod( 'blog_layout' ) == 'standard' ) {
				$classes[] = 'card mb-4';
			}
			else {
				$classes[] = 'card mb-4';
			}
			if ( ! get_theme_mod( 'card_style' ) || get_theme_mod( 'card_style' ) == 'border' ) {
				$classes[] = 'card-border';
			}
			elseif ( get_theme_mod( 'card_style' ) == 'noborder' ) {
				$classes[] = 'card-noborder';
			}
			else {
				$classes[] = 'card-shadow';
			}
		}
	}
	
	return $classes;
}
add_action( 'post_class', 'blogbaster_post_classes' );

/**
 * Print markup of bootstrap's card component
 */
function blogbaster_card_wrap_start(){
	echo '<div class="card-body">';
}
function blogbaster_card_wrap_end(){
	echo '</div><!--.card-body-->';
}
if ( get_theme_mod( 'content_boxed' ) == 1 ) {
	add_action( 'blogbaster_header_before', 'blogbaster_card_wrap_start' );
	add_action( 'blogbaster_article_end', 'blogbaster_card_wrap_end' );
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... 
 * and the read more button.
 *
 * @return string link
 */
function blogbaster_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}
	if ( '' != get_theme_mod( 'more_link' ) ) {
		$link = '...';
	} else {
		$link = '...';
	}
	return $link;
}
add_filter( 'excerpt_more', 'blogbaster_excerpt_more' );

function blogbaster_more_link($more_link, $more_link_text) {
	if ( '' != get_theme_mod( 'more_link' ) ) {
		$link_txt = esc_html( get_theme_mod( 'more_link' ) );
		return str_replace($more_link_text, $link_txt, $more_link);
	} else {
		return false;
	}
}
add_filter('the_content_more_link', 'blogbaster_more_link', 10, 2);

/**
 * Responsive Image class from Bootstrap
 * which appended to automatically generated image classes
 */
function blogbaster_bootstrap_class_images( $html ){
	$classes = 'img-fluid'; // separated by spaces, e.g. 'img image-link'
	// check if there are already classes assigned to the anchor
	if ( preg_match('/<img.*? class="/', $html) ) {
		$html = preg_replace('/(<img.*? class=".*?)(".*?\/>)/', '$1 ' . $classes . '$2', $html);
	} else {
		$html = preg_replace('/(<img.*?)(\/>)/', '$1 class="' . $classes . '"$2', $html);
	}
	return $html;
}
add_filter( 'the_content','blogbaster_bootstrap_class_images', 10 );

/**
 * Added table class from Bootstrap
 */
function blogbaster_bootstrap_table_class( $content ){
    return str_replace( '<table', '<table class="table"', $content );
}
add_filter( 'the_content', 'blogbaster_bootstrap_table_class' );

/**
 * Adds a class to the navigation links of posts
 */
function blogbaster_posts_link_attributes() {
	return 'class="btn btn-secondary"';
}
add_filter('next_posts_link_attributes', 'blogbaster_posts_link_attributes');
add_filter('previous_posts_link_attributes', 'blogbaster_posts_link_attributes');

/**
 * Comment form container.
 */
function blogbaster_comment_form_wrap_start(){
	echo '<div class="card my-4"><div class="card-body">';
}
function blogbaster_comment_form_wrap_end(){
	echo '</div></div>';
}
add_action( 'comment_form_after', 'blogbaster_comment_form_wrap_end' );
add_action( 'comment_form_before', 'blogbaster_comment_form_wrap_start' );

/**
 * Add custom class to comment reply link.
 */
function blogbaster_comment_reply_link( $content ) {
    $extra_classes = 'btn btn-primary';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $extra_classes, $content );
}
add_filter( 'comment_reply_link', 'blogbaster_comment_reply_link', 99 );

/**
 * Custom Excerpt lengths.
 */
function blogbaster_custom_excerpt_length($length) {
    if ( is_admin() ) {
    	return $length;
    }
    return 32;
}
add_filter( 'excerpt_length', 'blogbaster_custom_excerpt_length' );

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 * @param string $template front-page.php.
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function blogbaster_front_page( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'blogbaster_front_page' );


/**
 * 
 * Return an alternative title, without prefix
 * for every type used in the get_the_archive_title()
 * 
 */
function blogbaster_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
        $title = single_tag_title( '#', false );
    } elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif ( is_year() ) {
        $title = get_the_date( 'Y' );
    } elseif ( is_month() ) {
        $title = get_the_date( 'F Y' );
    } elseif ( is_day() ) {
        $title = get_the_date( get_option( 'date_format' ) );
    } elseif ( is_tax( 'post_format' ) ) {
        if ( is_tax( 'post_format', 'post-format-aside' ) ) {
            $title = esc_html( _x( 'Asides', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
            $title = esc_html( _x( 'Galleries', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
            $title = esc_html( _x( 'Images', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
            $title = esc_html( _x( 'Videos', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
            $title = esc_html( _x( 'Quotes', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
            $title = esc_html( _x( 'Links', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
            $title = esc_html( _x( 'Statuses', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
            $title = esc_html( _x( 'Audio', 'post format archive title', 'blogbaster' ) );
        } elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
            $title = esc_html( _x( 'Chats', 'post format archive title', 'blogbaster' ) );
        }
    } elseif ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    } elseif ( is_tax() ) {
        $title = single_term_title( '', false );
    } else {
        $title = __( 'Archives', 'blogbaster' );
    }
    return $title;
}
add_filter( 'get_the_archive_title', 'blogbaster_archive_title' );